from flater.winforms.application import Application
from flater.winforms.button import Button
from flater.winforms.control import Control
from flater.winforms.form import Form

from System.Windows.Forms import AnchorStyles


N = AnchorStyles.Top
S = AnchorStyles.Bottom
W = AnchorStyles.Left
E = AnchorStyles.Right
