from flater import LoadTelerik

LoadTelerik()

from flater.winforms.telerik.rad_button import RadButton
from flater.winforms.telerik.rad_control import RadControl
from flater.winforms.telerik.rad_control_spy_form import RadControlSpyForm
from flater.winforms.telerik.rad_form import RadForm

from flater.winforms.telerik.themes import *
